OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Календар",
    "Too many redirects. Aborting ..." : "Забагато перенаправлень. Скасовую...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Віддалений сервер не дає нам доступ до календаря (HTTP {%s} помилок)",
    "Error connecting to remote server" : "Помилка з'єднання з віддаленим сервером",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Помилка при запиті ресурсу на віддаленому сервері. Це може можливо бути пов'язано з невідповідністю сертифіката",
    "Error requesting resource on remote server" : "Помилка при запиті ресурсів на віддаленому сервері",
    "Individual" : "індивідуальний",
    "Group" : "Група",
    "Resource" : "Ресурс",
    "Room" : "Кімната",
    "Unknown" : "Невідомо",
    "Required" : "Вимагається",
    "Optional" : "Опціонально",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Ви перебуваєте в невідомому часовому поясі ({tz}), відкотитися до UTC",
    "Please create a calendar first." : "Будь ласка, створіть календар в першу чергу.",
    "New event" : "Нова подія",
    "CalDAV address for clients" : "CalDAV адреса для клієнтів",
    "Error saving WebCal-calendar" : "Помилка при збереженні WebCal-календаря",
    "WebDAV address for subscriptions" : "WebDAV адреса для підписки",
    "group" : "група",
    "Details" : "Деталі",
    "Attendees" : "Учасників",
    "Reminders" : "Нагадування",
    "Repeating" : "Повторення",
    "Confirmed" : "Підтверджено",
    "Tentative" : "Попередній",
    "Cancelled" : "Відмінено",
    "Global" : "Загальний",
    "None" : "Жоден",
    "Every day" : "Щоденно",
    "Every week" : "Щотижня",
    "Every month" : "Щомісяця",
    "Every year" : "Щорічно",
    "never" : "ніколи",
    "after" : "після",
    "How about getting started by importing some calendars?" : "Як щодо початку роботи за рахунок імпорту деяких календарів?",
    "At time of event" : "Час події",
    "5 minutes before" : "за 5 хвилин",
    "10 minutes before" : "за 10 хвилин",
    "15 minutes before" : "за 15 хвилин",
    "30 minutes before" : "за 30 хвилин",
    "1 hour before" : "за 1 годину",
    "2 hours before" : "за 2 години",
    "Audio" : "Аудіо",
    "Pop-up" : "Виринаюче вікно",
    "sec" : "сек",
    "min" : "хв",
    "hours" : "годин",
    "days" : "днів",
    "week" : "тиждень",
    "before" : "за",
    "start" : "початок",
    "end" : "кінець",
    "Editing reminders of unknown type not supported." : "Редагування нагадування невідомого типу не підтримується.",
    "Week {number} of {year}" : "Тиждень {number} з {year}",
    "Title of the Event" : "Назва події",
    "Delete" : "Видалити",
    "Cancel" : "Скасувати",
    "More ..." : "Більше ...",
    "Create" : "Створити",
    "Update" : "Оновити",
    "Close" : "Закрити",
    "Location" : "Місце",
    "Description" : "Опис",
    "Export" : "Експорт",
    "Day" : "День",
    "Week" : "Тиждень",
    "Month" : "Місяць",
    "Today" : "Сьогодні",
    "Share Calendar" : "Розподілити Календар",
    "Shared" : "Опубліковано",
    "More" : "Більше",
    "Edit" : "Редагувати",
    "Link" : "Посилання",
    "Download" : "Завантажити",
    "can edit" : "може редагувати",
    "New Calendar" : "Новий Календар",
    "Name" : "Ім’я",
    "New Subscription" : "Нова підписка",
    "Edit event" : "Редагувати подію",
    "Delete Event" : "Видалити подію",
    "Save Event" : "Зберегти подію",
    "Time" : "Час",
    "Type" : "Тип",
    "Repeat" : "Повторювати",
    "Add" : "Додати",
    "from" : "З",
    "to" : "в",
    "Import Calendars" : "Імпортувати календарі",
    "Import canceled" : "Імпорт скасовано",
    "Analyzing calendar" : "Аналізую календар",
    "New calendar" : "Новий календар",
    "Import calendar" : "Імпортувати календар",
    "No Calendars selected for import" : "Не обрані календарі для імпорту",
    "Primary CalDAV address" : "Первинна CalDAV адреса",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV адреса"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
